#Script for creating station objects
#Author: Byman H. Hamadudu
#Modifications: Erle Kristvik, Spring 2015 Trondheim, Norway

library(reshape2);library(hydroTSM);library(xlsx);
library(zoo);library(clim.pact)

setwd("path2files") 
    
# create list of all files with "pr" in the filename
files <- list.files(pattern = "pr")   
	
# read the first file of the list "files" 
dat<-read.xlsx(files[1],header=TRUE,1)

# create zoo object
ppt.z <- zoo(dat$RR,as.Date(paste(dat$Date),"%Y-%m-%d"))
  
#create a monthly time series
ppt.zm<-daily2monthly(ppt.z,FUN="sum")
assign(files[1],ppt.zm)  
	
	
#for Temperature reading ------------------------------------
	
tfiles <- list.files(pattern = "tas")
tdat<-read.xlsx(tfiles[1], header=TRUE,1)
tmp.z <- zoo(tdat$TAM,as.Date(paste(tdat$Dato),"%Y-%m-%d"))

#create a monthly time series
		tmp.zm<-daily2monthly(tmp.z,FUN="mean")
		assign(tfiles[1],tmp.zm)  

#If there is need to plot the data ---------------------------
# Plotting the monthly values
#	plot(tmp.zm, xlab="Time",ylab="Prec (mm)")
# Plotting the annual moving average in station 'x'
#lines(ma(tmp.zm, win.len=20), col="blue")
#lmm <- lm(coredata(ppt.zm) ~ index(ppt.zm)-1)
#plot(lmm,col="red")

#write the dat to files 
write.zoo(tas_florida.xlsx, file = "florida_tas.csv",
  index.name = "Index", row.names = FALSE, col.names = NULL)
write.zoo(pr_florida.xlsx, file = "florida_pr.csv",
  index.name = "Index", row.names = FALSE, col.names = NULL)

# reshape
myObjects <- NULL
myObjects[[1]] <-pr_florida.xlsx
myObjects[[2]] <-tas_florida.xlsx
	
names(myObjects) <- c("florida_pr","florida_tas")

for(i in 1:length(myObjects)){
df<-data.frame(
year=substr(index(myObjects[[i]]),1,4),
mons=substr(index(myObjects[[i]]),6,7),
dat=coredata(myObjects[[i]]))
	
dfr<-reshape(df, idvar="year",timevar="mons",direction = "wide")
write.csv(dfr,file = paste(names(myObjects)[i],".csv",sep=""),
          row.names = FALSE, col.names = TRUE)
}
	
temper <- read.csv(file="florida_tas.csv", header=TRUE, sep=",")
precip <- read.csv(file="florida_pr.csv", header=TRUE, sep=",")

# Create station object for precipitation

  names(precip) <- c("year", month.abb) 
  val <- as.matrix(precip[,2:13])
  yy <- precip[,1] 
  station <- 50540
  lat <- 60.3830
  lon <- 5.3327
  alt <- 12
  xyx <- NULL
  xyy <- NULL
  location <- "Bergen_Florida"
  wmo.no <- 50540
  start <- 1904
  yy0 <- 1900
  ele <- 601
  obs.name <- "Monthly precipitation"
  unit <- "mm/month"
  country <- "Norway"
ref <- "eklima.no/met.no"

bf_p <- station.obj(val, yy = yy, station = station, 
        lat = lat, lon = lon, alt = alt,  
        location = location, wmo.no = wmo.no, start = start, 
        yy0 = NULL, ele = ele, obs.name = obs.name, 
        unit = unit, country = country,  ref = ref)	
save(bf_p, file ="Bergen_Florida_pr.Rdata")

# Create station object for temperature

names(temper) <- c("year", month.abb) 
val <- as.matrix(temper[,2:13])
yy <- temper[,1] 
station <- 50540
lat <- 60.3830
lon <- 5.3327
alt <- 12
xyx <- NULL
xyy <- NULL
location <- "Bergen_Florida"
wmo.no <- 50540
start <- 1904
yy0 <- 1900
ele <- 101
obs.name <- "Mean monthly temperature"
unit <- "degC"
country <- "Norway"
ref <- "eklima.no/met.no"


bf_t <- station.obj(val, yy = yy, station = station, 
        lat = lat, lon = lon, alt = alt,  
        location = location, wmo.no = wmo.no, start = start, 
        yy0 = NULL, ele = ele, obs.name = obs.name, 
        unit = unit, country = country,  ref = ref)  
save(bf_t, file ="Bergen_Florida_tas.Rdata")
